@@ -2,10 +2,11 @@
 import os
 import sys
 import argparse
+from ._vendor import toml
 from .container import Container
 
 
-def run():
+def setup_parser():
     parser = argparse.ArgumentParser("rezup")
     parser.add_argument("-V", "--version", action="store_true",
                         help="show version and exit.")
@@ -21,10 +22,18 @@ def run():
     parser_use = subparsers.add_parser("use", help="use container")
     parser_use.add_argument("name", nargs="?", default=".main",
                             help="container name. default: '.main'")
-    parser_use.add_argument("-m", "--make",
-                            nargs="?", const=True, default=False,
-                            help="create new revision.")
-    parser_use.add_argument("-d", "--do", help="shell script. Not implemented.")
+    parser_use.add_argument("-d", "--do", help="run a shell script and exit.")
+
+    # cmd: add
+    #
+    parser_add = subparsers.add_parser("add", help="add container revision")
+    parser_add.add_argument("name", nargs="?", default=".main",
+                            help="container name. default: '.main'")
+    parser_add.add_argument("-r", "--remote", help="add a remote revision.",
+                            action="store_true")
+    parser_add.add_argument("-f", "--file", help="recipe file to make.")
+    parser_add.add_argument("--skip-use", help="add revision and exit.",
+                            action="store_true")
 
     # cmd: drop
     #
@@ -42,6 +51,31 @@ def run():
     # TODO: able to *pull* revision from container to another
     # TODO: an interface to pin/tag container revision (if needed)
 
+    return parser
+
+
+def site_customize():
+    startup_recipe = os.path.expanduser("~/rezup.toml")
+    if not os.path.isfile(startup_recipe):
+        return
+
+    init_cfg = toml.load(startup_recipe).get("init") or dict()
+    script = init_cfg.get("script")
+    if not script or not os.path.isfile(script):
+        return
+
+    g = dict(
+        __name__=os.path.splitext(os.path.basename(script))[0],
+        __file__=script,
+    )
+    with open(script) as f:
+        code = compile(f.read(), script, "exec")
+        exec(code, g)
+
+
+def run():
+    parser = setup_parser()
+
     # for fast access
     if len(sys.argv) == 1:
         sys.argv += ["use", ".main"]
@@ -56,12 +90,21 @@ def run():
         from .upgrade import show_latest
         sys.exit(show_latest())
 
+    # important step for diversity setup
+    site_customize()
+
     if not (opts.no_upgrade or os.getenv("REZUP_NO_UPGRADE")):
         from .upgrade import auto_upgrade
         auto_upgrade()
 
     if opts.cmd == "use":
-        cmd_use(opts.name, make=opts.make, job=opts.do)
+        cmd_use(opts.name, job=opts.do)
+
+    if opts.cmd == "add":
+        cmd_add(opts.name,
+                remote=opts.remote,
+                recipe=opts.file,
+                skip_use=opts.skip_use)
 
     elif opts.cmd == "drop":
         cmd_drop(opts.name)
@@ -70,37 +113,43 @@ def run():
         cmd_inventory()
 
 
-def cmd_use(name, make=None, job=None):
-    if make:
-        recipe = None if isinstance(make, bool) else make
-        container = Container.create(name)
-        revision = container.new_revision(recipe_file=recipe)
-    else:
-        container = Container(name)
-        revision = container.get_latest_revision()
+def cmd_use(name, job=None):
+    container = Container(name)
+    revision = container.get_latest_revision()
 
-        if not revision:
-            if container.is_exists():
-                print("Container '%s' exists but has no valid revision: %s"
-                      % (container.name(), container.path()))
-                sys.exit(1)
+    if not revision:
+        if container.is_exists():
+            print("Container '%s' exists but has no valid revision: %s"
+                  % (container.name(), container.path()))
+            sys.exit(1)
 
-            elif container.name() != ".main":
-                print("Container '%s' not exist, use --make to create."
-                      % container.name())
-                sys.exit(1)
+        elif container.name() != ".main":
+            print("Container '%s' not exist, use --make to create."
+                  % container.name())
+            sys.exit(1)
 
-            else:
-                # for quick first run
-                print("Creating default container automatically for first "
-                      "run..")
-                revision = container.new_revision()
+        else:
+            # for quick first run
+            print("Creating default container automatically for first "
+                  "run..")
+            revision = container.new_revision()
 
     sys.exit(
         revision.use(run_script=job)
     )
 
 
+def cmd_add(name, remote=False, recipe=None, skip_use=False):
+    root = Container.remote_root() if remote else Container.local_root()
+    container = Container.create(name, root=root)
+    revision = container.new_revision(recipe_file=recipe)
+
+    if not skip_use:
+        sys.exit(
+            revision.use()
+        )
+
+
 def cmd_drop(name):
     container = Container(name)
     container.purge()
