@@ -200,6 +200,10 @@ class Revision:
         if not self._container.is_remote():
             self._install(recipe)
 
+        # cleanup entries that revision doesn't need
+        #
+        recipe.pop("init", None)
+
         # save recipe, mark as ready
         #
         with open(self._recipe, "w") as f:
@@ -348,7 +352,7 @@ class Revision:
         if self.is_remote():
             # use local
             revision = self.pull()
-            return revision.use()
+            return revision.use(run_script=run_script)
 
         else:
             # Launch subprocess
